% Cell migration in 2D model, random walk, substrate thicknesses
clear all; clc;
%%
% parameters
R = 50;                                          %Cell raduis (mic m)
t = 0:1:3*10^2;                                  %Time interval (sec)
m = length(t);                                   %no. of iteration
% Cells coordinate
[x, y] = circles(R);
% x = [255, -255, -255, 255];
% y = [255, 255, -255, -255];
% 
%%
ks = 10^-3;                              %cell-substrate interaction
Beta_0 = 5 * 10^-15;                     %Drag constant (Ns/mm^3)
I = 5490;                                %Free integrins density (mol/mm)
Fr = 3.33;                               %Front-rear dissociation asymmetry
gama = @(z)(Fr + (1 - Fr)*((z)/(2 * R)));
const = 2 * integral(gama, 0, R, 'ArrayValued', true);
drag = (Beta_0 * ks * I) * const^-1;
%
%%
% Vectors: Calculate the distance between each cell and divide by norm
[SED_f, vec_x, vec_y] = Thickness(x, y, R);
% 
% Displacment equation with directed motion (fully deterministic)
% xcoor = [];                           ycoor = [];
x1 = x;           y1 = y;
SED_n = SED_f;    vecx_n = vec_x;     vecy_n = vec_y;
for l = 1 : m
    xn = [];
    yn = [];
    for i = 1 : length(x1)
        [dirx, diry] = random(m);
        X = (1/drag) * t(l) * SED_n(i) * vecx_n(i) + x1(i) + dirx;
        Y = (1/drag) * t(l) * SED_n(i) * vecy_n(i) + y1(i) + diry;
        xn = [xn, X];
        yn = [yn, Y];
    end
    x1 = xn;
    y1 = yn;
    [SED_n, vecx_n, vecy_n] = Thickness(xn, yn, R);
%     figure    
    MCircles(xn, yn, R);
    hold on;
    set(0,'DefaultAxesFontSize',22)
    set(0,'DefaultAxesFontName', 'Times New Roman')
    set(gca,'FontSize', 18, 'LineWidth', 2);
    axis square
    box on;
    ylabel('Y-coordinate (\mum)','FontName','times new roman', ...,
        'fontweight','bold','fontsize',22,'LineWidth', 2);
    xlabel('X-coordinate (\mum)','FontName','times new roman', ...,
        'fontweight','bold','fontsize',22,'LineWidth', 2);
    text(50,-400, '\fontname{times new roman}{\it{h}} = 100 \mum','FontSize',18);
    text(-430,-400, '\fontname{times new roman}{\it{h}} = 300 \mum','FontSize',18);
    figure(1);
    clf
%     print('-dmeta',['thickness_',num2str(l) '.emf'])
%     print('-dpdf',['regions_',num2str(l) '.pdf']);
%     print('-depsc',['regions_',num2str(l) '.eps']);
    text(200,450, ['\fontname{Cambria Math}{\it{t}} = ', int2str(l), ...
        ' \fontname{times new roman}s'],'FontSize',18);
%     saveas(gcf,['V_',num2str(l) '.png']);
%     close
end
%
% % save images as .avi video
% for n = 1 : m
%     images{n} = imread(sprintf('V_%d.png', n));
% end
% writerObj = VideoWriter('Thickness with random motion.avi');
% writerObj.FrameRate = 10;
% open(writerObj)
% for u = 1 : length(images)
%     frame = im2frame(images{u});
%     writeVideo(writerObj, frame)
% end
% close(writerObj)