function[SED, vectorx, vectory] = Thickness(x, y, R)
% Calculate strain energy density and their vectors when the substrate
% elasiticity has two values
% Parameters
p = (1 * 10^-9)/(pi * (R)^2);                  %Pressure (N/mic m^2)
v = 0.3;                                       %Poisson's ratio
E = 5 * 10^-9;                                 %Young modulus(KPa)(N/mic m^2)
k0 = (E) * ((1 - v)/((1 + v) * (1 - 2 * v)));
%
% S_m = [];
SE_m = zeros(length(x),1);
for a = 1 : length(x)
    if x(a) >= 0 
       h = 100;                                %Substrate thickness (mic m)
    elseif x(a) < 0
       h = 300;
    end
% Stiffness (N/mic m^3)
    k = k0/h;
%Co-operating width (mic m)
    b = (0.156 * h) * ((1 - (2 * v))/((1 - v)^2));
    s = 1/b;
% Deformation under cell (mic m)
    w = @(alpha)(p/k) * (1 - (exp(-s * R) * cosh(alpha * s)));
% Strain energy in spring model under the cell (N)
    U = @(alpha)2 * k * (w(alpha))^2 * sqrt(R^2 - (alpha)^2);
% Strain energy density under the cell (J/mic m^3)):
    S = strain(U, 0, R);
    SE = S/(pi * (R^2) * h);
    SE_m(a) = SE;
end
%
SED_vx = [];
SED_vy = [];
SED_m = [];
for c1 = 1 : length(x)
    for c2 = 1 : length(x)
        if c1 ~= c2
           dist_x = x(c2) - x(c1);
           dist_y = y(c2) - y(c1);
           dist = abs(((dist_x)^2 + (dist_y)^2)^0.5);
           if dist < 2 * R
              dist_x = x(c1) - x(c2);
              dist_y = y(c1) - y(c2);
              dist = abs(((dist_x)^2 + (dist_y)^2)^0.5);
           end
           D_dist = dist^2 - R^2;
           if D_dist < 2*R
              D_dist = 2 * R;
           end
           if (x(c1) >= 0 && x(c2) >= 0)
              h = 100;
              k = k0/h;
              b = (0.156 * h) * ((1 - (2 * v))/((1 - v)^2));
              s = 1/b;
% Deformation outside cell (mic m)
              w1 = @(beta)(p/k) * exp(-s * beta) * sinh(s * R);
% Strain energy in spring model outside the cell (N)
              U1 = @(beta)k * (w1(beta))^2 * pi * beta;
% Strain energy from other cells (J [N mic m]):
              SEv = strain(U1, R, dist);
% Strain energy density (J/mic m^3):
              SED_v = (SEv)/(pi * (D_dist) * h);
           elseif (x(c1) < 0 && x(c2) < 0)
              h = 300;
              k = k0/h;
              b = (0.156 * h) * ((1 - (2 * v))/((1 - v)^2));
              s = 1/b;
              w2 = @(beta)(p/k) * exp(-s * beta) * sinh(s * R);
              U2 = @(beta)k * (w2(beta))^2 * pi * beta;
              SEv = strain(U2, R, dist);
              SED_v = (SEv)/(pi * (D_dist) * h);
           elseif ((x(c1) >= 0 && x(c2) < 0) || (x(c1) < 0 && x(c2) >= 0))
              yy = y(c1) - ((x(c1) * (y(c2) - y(c1)))/(x(c2) - x(c1)));
              axe_dist = abs(((x(c1))^2 + (y(c1) - yy)^2)^0.5);
%               if abs(axe_dist) <= R
%                  axe_dist = 1.1 * R;
%               end
              if x(c1) >= 0 && x(c2) < 0
                 h = 100;
                 h1 = 300;
              elseif x(c1) < 0 && x(c2) >= 0
                 h = 300;
                 h1 = 100;
              end
                 k = k0/h;
                 b = (0.156 * h) * ((1 - (2 * v))/((1 - v)^2));
                 s = 1/b;
                 w3 = @(beta)(p/k) * exp(-s * beta) * sinh(s * R);
                 U3 = @(beta)k * (w3(beta))^2 * pi * beta;
                 k1 = k0/h1;
                 w4 = @(zeta)(p/k1) * exp(-s * zeta) * sinh(s * R);
                 U4 = @(zeta)k1 * (w4(zeta))^2 * pi * zeta;
                 SEv = strain(U3, R, axe_dist) + ...,
                  strain(U4, axe_dist, dist);
                 if axe_dist <= R
                    SEv = strain(U4, R, dist);
                 end
                 SED_v = (SEv)/(pi * (D_dist) * h);
           end
           SED_m = [SED_m, SED_v];
% Unit vector of each cell:
           xv = dist_x/abs(dist);
           yv = dist_y/abs(dist);
           vecx = SED_v * xv;
           vecy = SED_v * yv;
           SED_vx = [SED_vx, vecx];
           SED_vy = [SED_vy, vecy];
        end
    end
end
SEDx = zeros(length(x),length(x)-1);
SEDy = zeros(length(x),length(x)-1);
SED_tot = zeros(length(x),length(x)-1);
id = 1;
for i = 1 : length(x)
    for j = 1 : length(x) - 1
        SEDx(i, j) = SED_vx(id);
        SEDy(i, j) = SED_vy(id);
        SED_tot(i, j) = SED_m(id);
        id = id + 1;
    end
end
% Cell displacement over time frame is parallel to:
Ax = sum(SEDx,2);
Ay = sum(SEDy,2);
% Resultant vector (direction of motion):
dist_vec = abs((Ax.^2 + Ay.^2).^0.5);
vectorx = Ax./dist_vec;
vectory = Ay./dist_vec;
% Total strain energy (J/mic m^3)
SED = SE_m + sum(SED_tot,2);
end